
#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators.PHX  //Brush Logic example in Trends indie
{
	
	public class PHX_LagTime : Indicator
		{
			
		Brush FontColor;
	    string sDiff="";
		
		// FormatPriceMarker method of a custom indicator
		public override string FormatPriceMarker(double price)
		{
		    // Formats price marker values to 4 decimal places
		    return price.ToString("N4");
		} 	
		
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description					= @"";
				Name						= "PHX_LagTime";
				Calculate					= Calculate.OnBarClose;
				IsOverlay					= true;
				DisplayInDataBox			= true; 
				DrawOnPricePanel			= true;
				PaintPriceMarkers			= true;
				IsSuspendedWhileInactive	= true;
				
				DisplayOutputWindow			= false;
				DisplayChart				= true;
				//FontColor					= Brushes.Yellow;
				TxtPos						= TextPosition.BottomRight;
				MaxTradeSec					= 0.04;
				MaxOptimumSec				= 0.03;
				TopColor					= Brushes.Red;
				MiddleColor					= Brushes.Yellow;
				BottomColor					= Brushes.LimeGreen;
						
			}
			else if (State == State.Configure)
			{
	
			}
			else if (State == State.Historical)
			{
				SetZOrder(-Int32.MaxValue);
			}				
		}
		
		protected override void OnBarUpdate()
		{	
			if (CurrentBars[0]<BarsRequiredToPlot )
			{return;}

			if (State == State.Realtime)
			{
				TimeSpan DiffTS = Time[0] - DateTime.Now;
				if (DiffTS.TotalSeconds<0) sDiff="n/a";
				
				else sDiff=DiffTS.TotalSeconds.ToString("n3")+" sec" ;  //+"."+DiffTS.TotalMilliseconds.ToString();
				string sOutput="Delay:"+sDiff+"  BarClose="+Time[0].ToString("HH:mm:ss.fff")+"  Now="+DateTime.Now.ToString("HH:mm:ss.fff");
				if (DisplayOutputWindow) {Print(sOutput);}
				//Draw.Text(this, "TS"+CurrentBar, "Delay:"+s+" ms", 0, Close[0]+1, Brushes.Yellow);
				if (DisplayChart)
				{
					if (DiffTS.TotalSeconds>MaxTradeSec)
					{FontColor=TopColor;}
					else if (DiffTS.TotalSeconds<MaxOptimumSec) {FontColor=BottomColor;}
					else {FontColor=MiddleColor;}
					
					Draw.TextFixed(this,"TS"+CurrentBar,sDiff,TxtPos,FontColor,
							  ChartControl.Properties.LabelFont,Brushes.Transparent,Brushes.Transparent,0);
					RemoveDrawObject("TS"+(CurrentBar-1));
				}
			}
		}//onbarupdate
		
        [NinjaScriptProperty]
        [Display(Name = "Display OutputWindow", GroupName = "Base", Order = 0)]
        public bool DisplayOutputWindow
		{ get; set; }			
		
        [NinjaScriptProperty]
        [Display(Name = "Display Chart", GroupName = "Base", Order = 1)]
        public bool DisplayChart
		{ get; set; }	
		
		[NinjaScriptProperty]
        [Display(Name = "Display Chart", GroupName = "Base", Order = 2)]
        public TextPosition TxtPos
		{ get; set; }	
		
		[NinjaScriptProperty]
        [Display(Name = "Max Trade (sec)", GroupName = "Base", Order = 3)]
        public double MaxTradeSec
		{ get; set; }	
		
		[NinjaScriptProperty]
        [Display(Name = "Max Optimum (sec)", GroupName = "Base", Order = 4)]
        public double MaxOptimumSec
		{ get; set; }			
		
		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(Name="Top Color", Order=5, GroupName="Base")]
		public Brush TopColor
		{ get; set; }

		[Browsable(false)]
		public string IndicatorTopColorSerializable
		{
		    get { return Serialize.BrushToString(TopColor); }
		    set { TopColor = Serialize.StringToBrush(value); }
		}			
		
		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(Name="Middle Color", Order=5, GroupName="Base")]
		public Brush MiddleColor
		{ get; set; }

		[Browsable(false)]
		public string IndicatorMiddleColorSerializable
		{
		    get { return Serialize.BrushToString(MiddleColor); }
		    set { MiddleColor = Serialize.StringToBrush(value); }
		}	
		
		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(Name="Bottom Color", Order=5, GroupName="Base")]
		public Brush BottomColor
		{ get; set; }

		[Browsable(false)]
		public string IndicatorBottomColorSerializable
		{
		    get { return Serialize.BrushToString(BottomColor); }
		    set { BottomColor = Serialize.StringToBrush(value); }
		}		
			
	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private PHX.PHX_LagTime[] cachePHX_LagTime;
		public PHX.PHX_LagTime PHX_LagTime(bool displayOutputWindow, bool displayChart, TextPosition txtPos, double maxTradeSec, double maxOptimumSec, Brush topColor, Brush middleColor, Brush bottomColor)
		{
			return PHX_LagTime(Input, displayOutputWindow, displayChart, txtPos, maxTradeSec, maxOptimumSec, topColor, middleColor, bottomColor);
		}

		public PHX.PHX_LagTime PHX_LagTime(ISeries<double> input, bool displayOutputWindow, bool displayChart, TextPosition txtPos, double maxTradeSec, double maxOptimumSec, Brush topColor, Brush middleColor, Brush bottomColor)
		{
			if (cachePHX_LagTime != null)
				for (int idx = 0; idx < cachePHX_LagTime.Length; idx++)
					if (cachePHX_LagTime[idx] != null && cachePHX_LagTime[idx].DisplayOutputWindow == displayOutputWindow && cachePHX_LagTime[idx].DisplayChart == displayChart && cachePHX_LagTime[idx].TxtPos == txtPos && cachePHX_LagTime[idx].MaxTradeSec == maxTradeSec && cachePHX_LagTime[idx].MaxOptimumSec == maxOptimumSec && cachePHX_LagTime[idx].TopColor == topColor && cachePHX_LagTime[idx].MiddleColor == middleColor && cachePHX_LagTime[idx].BottomColor == bottomColor && cachePHX_LagTime[idx].EqualsInput(input))
						return cachePHX_LagTime[idx];
			return CacheIndicator<PHX.PHX_LagTime>(new PHX.PHX_LagTime(){ DisplayOutputWindow = displayOutputWindow, DisplayChart = displayChart, TxtPos = txtPos, MaxTradeSec = maxTradeSec, MaxOptimumSec = maxOptimumSec, TopColor = topColor, MiddleColor = middleColor, BottomColor = bottomColor }, input, ref cachePHX_LagTime);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.PHX.PHX_LagTime PHX_LagTime(bool displayOutputWindow, bool displayChart, TextPosition txtPos, double maxTradeSec, double maxOptimumSec, Brush topColor, Brush middleColor, Brush bottomColor)
		{
			return indicator.PHX_LagTime(Input, displayOutputWindow, displayChart, txtPos, maxTradeSec, maxOptimumSec, topColor, middleColor, bottomColor);
		}

		public Indicators.PHX.PHX_LagTime PHX_LagTime(ISeries<double> input , bool displayOutputWindow, bool displayChart, TextPosition txtPos, double maxTradeSec, double maxOptimumSec, Brush topColor, Brush middleColor, Brush bottomColor)
		{
			return indicator.PHX_LagTime(input, displayOutputWindow, displayChart, txtPos, maxTradeSec, maxOptimumSec, topColor, middleColor, bottomColor);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.PHX.PHX_LagTime PHX_LagTime(bool displayOutputWindow, bool displayChart, TextPosition txtPos, double maxTradeSec, double maxOptimumSec, Brush topColor, Brush middleColor, Brush bottomColor)
		{
			return indicator.PHX_LagTime(Input, displayOutputWindow, displayChart, txtPos, maxTradeSec, maxOptimumSec, topColor, middleColor, bottomColor);
		}

		public Indicators.PHX.PHX_LagTime PHX_LagTime(ISeries<double> input , bool displayOutputWindow, bool displayChart, TextPosition txtPos, double maxTradeSec, double maxOptimumSec, Brush topColor, Brush middleColor, Brush bottomColor)
		{
			return indicator.PHX_LagTime(input, displayOutputWindow, displayChart, txtPos, maxTradeSec, maxOptimumSec, topColor, middleColor, bottomColor);
		}
	}
}

#endregion
